@@ -1,7 +1,7 @@
-/* $Id: symon.h,v 1.31 2004/08/08 17:21:18 dijkstra Exp $ */
+/* $Id: symon.h,v 1.33 2005/03/20 16:17:22 dijkstra Exp $ */
 
 /*
- * Copyright (c) 2001-2004 Willem Dijkstra
+ * Copyright (c) 2001-2005 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,7 +39,7 @@
 #define SYMON_PID_FILE "/var/run/symon.pid"
 #define SYMON_DEFAULT_INTERVAL 5	/* measurement interval */
 #define SYMON_WARN_SENDERR 50	        /* warn every x errors */
-#define SYMON_MAX_DOBJECTS 2000	        /* max dynamic allocation; local limit per
+#define SYMON_MAX_DOBJECTS 10000	/* max dynamic allocation; local limit per
 					 * measurement module */
 #define SYMON_MAX_OBJSIZE (_POSIX2_LINE_MAX)
 #define SYMON_SENSORMASK 0xFF           /* sensors 0-255 are allowed */
@@ -49,8 +49,8 @@
  *
  * - privinit = priviledged init, called before chroot
  * - init     = called once, right after configuration
- * - gets     = called every monitor interval, can be used by modules that get all
- *              their measurements in one go.
+ * - gets     = called every monitor interval, can be used by modules that get
+ *              all their measurements in one go.
  * - get      = obtain measurement
  */
 struct funcmap {
@@ -91,6 +91,12 @@ extern void privinit_pf();
 extern void init_pf(char *);
 extern int get_pf(char *, int, char *);
 
+/* sm_pfq.c */
+extern void privinit_pfq();
+extern void init_pfq(char *);
+extern void gets_pfq();
+extern int get_pfq(char *, int, char *);
+
 /* sm_mbuf.c */
 extern void init_mbuf(char *);
 extern int get_mbuf(char *, int, char *);
