@@ -1,7 +1,7 @@
-/* $Id: symux.h,v 1.16 2002/11/29 10:45:22 dijkstra Exp $ */
+/* $Id: symux.h,v 1.19 2004/02/26 22:48:08 dijkstra Exp $ */
 
 /*
- * Copyright (c) 2001-2002 Willem Dijkstra
+ * Copyright (c) 2001-2004 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,7 +33,7 @@
 #ifndef _SYMUX_SYMUX_H
 #define _SYMUX_SYMUX_H
 
-#include "conf.h"
+#include <conf.h>
 
 #define SYMUX_PID_FILE "/var/run/symux.pid"
 
